<?php

namespace app\common\model\Enrol;

use app\common\arw\adjfut\src\Validate;
use app\BaseModel;
use think\model\concern\SoftDelete;
use app\common\arw\adjfut\src\Excel;
use app\Request;
use app\common\exception\Tool;
use think\facade\Db;

class SignUpProcess extends BaseModel
{
    use SoftDelete;
    // 删除字段
    protected $deleteTime = 'sign_up_process_delete_time';
    // 设置主键名
    protected $pk = 'sign_up_process_guid';
    // 设置废弃字段
    protected $disuse = [];
    // 设置字段信息
    protected $schema = [
	
            "sign_up_process_id" => "int",
            
            "sign_up_process_guid" => "string",
            
            "sign_up_process_title" => "string",
            
            "sign_up_process_icon" => "string",
            
            "sign_up_process_intro" => "string",
            
            "sign_up_process_sort" => "int",
            
            "sign_up_process_create_time" => "datetime",
            
            "sign_up_process_create_user_guid" => "string",
            
            "sign_up_process_update_time" => "datetime",
            
            "sign_up_process_update_user_guid" => "string",
            
            "sign_up_process_delete_time" => "datetime",
            
            "sign_up_process_delete_user_guid" => "string",
            
	];
    // 设置json类型字段
    protected $json = [''];
    // 开启自动写入时间戳字段
    protected $autoWriteTimestamp = 'datetime';
    // 创建时间
    protected $createTime = 'sign_up_process_create_time';
    // 修改时间
    protected $updateTime = 'sign_up_process_update_time';

    
    //排序字段
    public $order_field = 'sign_up_process_sort';

    /**
     * 新增前
     */
    public static function onBeforeInsert(self $model): void
    {
        Validate::unique(self::class, $model->sign_up_process_guid, $model->getData(), [
            'sign_up_process_title' => '报名流程标题',
        ]);
        Tool::sortInsertProc(
            self::class,
            $model->sign_up_process_sort,
        );
        $model->completeCreateField();
    }

    /**
     * 更新前
     */
    public static function onBeforeUpdate(self $model): void
    {
        Validate::unique(self::class, $model->sign_up_process_guid, $model->getData(), [
            'sign_up_process_title' => '报名流程标题',
        ]);
        Tool::sortEditProc(
            self::class,
            $model->sign_up_process_guid,
            $model->sign_up_process_sort,
        );
        $model->completeUpdateField();
    }

    /**
     * 删除前
     */
    public static function onBeforeDelete(self $model): void
    {
        Tool::sortDeleteProc(self::class, $model->sign_up_process_guid);
        $model->completeDeleteField();
    }

    
    /**
     * 导出Excel
     */
    public static function exportExcel($select)
    {
        $data = [[
            '报名流程标题',
            '报名流程标题介绍',
        ]];
        foreach ($select as $key => $val) {
            $data[] = [
                $val['sign_up_process_title'],
                $val['sign_up_process_intro'],
            ];
        }
        $excel = (new Excel())->exporTsheet($data);
        $excel->save('报名流程.xlsx');
    }
    


}
